# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BgpSpeakerV2Args', 'BgpSpeakerV2']

@pulumi.input_type
class BgpSpeakerV2Args:
    def __init__(__self__, *,
                 local_as: pulumi.Input[_builtins.int],
                 advertise_floating_ip_host_routes: Optional[pulumi.Input[_builtins.bool]] = None,
                 advertise_tenant_networks: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 peers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a BgpSpeakerV2 resource.

        :param pulumi.Input[_builtins.int] local_as: The local autonomous system number (ASN) for the BGP
               speaker. This is a mandatory field and must be specified. Changing this
               creates a new BGP speaker.
        :param pulumi.Input[_builtins.bool] advertise_floating_ip_host_routes: A boolean value indicating
               whether to advertise floating IP host routes. Defaults to `true`.
        :param pulumi.Input[_builtins.bool] advertise_tenant_networks: A boolean value indicating whether to
               advertise tenant networks. Defaults to `true`.
        :param pulumi.Input[_builtins.int] ip_version: The IP version of the BGP speaker. Valid values are
               `4` or `6`. Defaults to `4`. Changing this creates a new BGP speaker.
        :param pulumi.Input[_builtins.str] name: A name for the BGP speaker.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] networks: A list of network IDs to associate with the BGP speaker.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] peers: A list of BGP peer IDs to associate with the BGP speaker.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a Neutron network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new BGP
               speaker.
        :param pulumi.Input[_builtins.str] tenant_id: The tenant/project ID. Required if admin privileges
               are used. Changing this creates a new BGP speaker.
        """
        pulumi.set(__self__, "local_as", local_as)
        if advertise_floating_ip_host_routes is not None:
            pulumi.set(__self__, "advertise_floating_ip_host_routes", advertise_floating_ip_host_routes)
        if advertise_tenant_networks is not None:
            pulumi.set(__self__, "advertise_tenant_networks", advertise_tenant_networks)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if peers is not None:
            pulumi.set(__self__, "peers", peers)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter(name="localAs")
    def local_as(self) -> pulumi.Input[_builtins.int]:
        """
        The local autonomous system number (ASN) for the BGP
        speaker. This is a mandatory field and must be specified. Changing this
        creates a new BGP speaker.
        """
        return pulumi.get(self, "local_as")

    @local_as.setter
    def local_as(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "local_as", value)

    @_builtins.property
    @pulumi.getter(name="advertiseFloatingIpHostRoutes")
    def advertise_floating_ip_host_routes(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        A boolean value indicating
        whether to advertise floating IP host routes. Defaults to `true`.
        """
        return pulumi.get(self, "advertise_floating_ip_host_routes")

    @advertise_floating_ip_host_routes.setter
    def advertise_floating_ip_host_routes(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "advertise_floating_ip_host_routes", value)

    @_builtins.property
    @pulumi.getter(name="advertiseTenantNetworks")
    def advertise_tenant_networks(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        A boolean value indicating whether to
        advertise tenant networks. Defaults to `true`.
        """
        return pulumi.get(self, "advertise_tenant_networks")

    @advertise_tenant_networks.setter
    def advertise_tenant_networks(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "advertise_tenant_networks", value)

    @_builtins.property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The IP version of the BGP speaker. Valid values are
        `4` or `6`. Defaults to `4`. Changing this creates a new BGP speaker.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ip_version", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name for the BGP speaker.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of network IDs to associate with the BGP speaker.
        """
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "networks", value)

    @_builtins.property
    @pulumi.getter
    def peers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of BGP peer IDs to associate with the BGP speaker.
        """
        return pulumi.get(self, "peers")

    @peers.setter
    def peers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "peers", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a Neutron network. If omitted, the
        `region` argument of the provider is used. Changing this creates a new BGP
        speaker.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The tenant/project ID. Required if admin privileges
        are used. Changing this creates a new BGP speaker.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.input_type
class _BgpSpeakerV2State:
    def __init__(__self__, *,
                 advertise_floating_ip_host_routes: Optional[pulumi.Input[_builtins.bool]] = None,
                 advertise_tenant_networks: Optional[pulumi.Input[_builtins.bool]] = None,
                 advertised_routes: Optional[pulumi.Input[Sequence[pulumi.Input['BgpSpeakerV2AdvertisedRouteArgs']]]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.int]] = None,
                 local_as: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 peers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering BgpSpeakerV2 resources.

        :param pulumi.Input[_builtins.bool] advertise_floating_ip_host_routes: A boolean value indicating
               whether to advertise floating IP host routes. Defaults to `true`.
        :param pulumi.Input[_builtins.bool] advertise_tenant_networks: A boolean value indicating whether to
               advertise tenant networks. Defaults to `true`.
        :param pulumi.Input[Sequence[pulumi.Input['BgpSpeakerV2AdvertisedRouteArgs']]] advertised_routes: A list of dictionaries containing the `destination` and
               `next_hop` for each route advertised by the BGP speaker. This attribute is
               only populated after the BGP speaker has been created and has established BGP
               sessions with its peers.
        :param pulumi.Input[_builtins.int] ip_version: The IP version of the BGP speaker. Valid values are
               `4` or `6`. Defaults to `4`. Changing this creates a new BGP speaker.
        :param pulumi.Input[_builtins.int] local_as: The local autonomous system number (ASN) for the BGP
               speaker. This is a mandatory field and must be specified. Changing this
               creates a new BGP speaker.
        :param pulumi.Input[_builtins.str] name: A name for the BGP speaker.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] networks: A list of network IDs to associate with the BGP speaker.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] peers: A list of BGP peer IDs to associate with the BGP speaker.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a Neutron network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new BGP
               speaker.
        :param pulumi.Input[_builtins.str] tenant_id: The tenant/project ID. Required if admin privileges
               are used. Changing this creates a new BGP speaker.
        """
        if advertise_floating_ip_host_routes is not None:
            pulumi.set(__self__, "advertise_floating_ip_host_routes", advertise_floating_ip_host_routes)
        if advertise_tenant_networks is not None:
            pulumi.set(__self__, "advertise_tenant_networks", advertise_tenant_networks)
        if advertised_routes is not None:
            pulumi.set(__self__, "advertised_routes", advertised_routes)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if local_as is not None:
            pulumi.set(__self__, "local_as", local_as)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if peers is not None:
            pulumi.set(__self__, "peers", peers)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter(name="advertiseFloatingIpHostRoutes")
    def advertise_floating_ip_host_routes(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        A boolean value indicating
        whether to advertise floating IP host routes. Defaults to `true`.
        """
        return pulumi.get(self, "advertise_floating_ip_host_routes")

    @advertise_floating_ip_host_routes.setter
    def advertise_floating_ip_host_routes(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "advertise_floating_ip_host_routes", value)

    @_builtins.property
    @pulumi.getter(name="advertiseTenantNetworks")
    def advertise_tenant_networks(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        A boolean value indicating whether to
        advertise tenant networks. Defaults to `true`.
        """
        return pulumi.get(self, "advertise_tenant_networks")

    @advertise_tenant_networks.setter
    def advertise_tenant_networks(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "advertise_tenant_networks", value)

    @_builtins.property
    @pulumi.getter(name="advertisedRoutes")
    def advertised_routes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BgpSpeakerV2AdvertisedRouteArgs']]]]:
        """
        A list of dictionaries containing the `destination` and
        `next_hop` for each route advertised by the BGP speaker. This attribute is
        only populated after the BGP speaker has been created and has established BGP
        sessions with its peers.
        """
        return pulumi.get(self, "advertised_routes")

    @advertised_routes.setter
    def advertised_routes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BgpSpeakerV2AdvertisedRouteArgs']]]]):
        pulumi.set(self, "advertised_routes", value)

    @_builtins.property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The IP version of the BGP speaker. Valid values are
        `4` or `6`. Defaults to `4`. Changing this creates a new BGP speaker.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ip_version", value)

    @_builtins.property
    @pulumi.getter(name="localAs")
    def local_as(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The local autonomous system number (ASN) for the BGP
        speaker. This is a mandatory field and must be specified. Changing this
        creates a new BGP speaker.
        """
        return pulumi.get(self, "local_as")

    @local_as.setter
    def local_as(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "local_as", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name for the BGP speaker.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of network IDs to associate with the BGP speaker.
        """
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "networks", value)

    @_builtins.property
    @pulumi.getter
    def peers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of BGP peer IDs to associate with the BGP speaker.
        """
        return pulumi.get(self, "peers")

    @peers.setter
    def peers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "peers", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a Neutron network. If omitted, the
        `region` argument of the provider is used. Changing this creates a new BGP
        speaker.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The tenant/project ID. Required if admin privileges
        are used. Changing this creates a new BGP speaker.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.type_token("openstack:networking/bgpSpeakerV2:BgpSpeakerV2")
class BgpSpeakerV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 advertise_floating_ip_host_routes: Optional[pulumi.Input[_builtins.bool]] = None,
                 advertise_tenant_networks: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.int]] = None,
                 local_as: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 peers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a V2 Neutron BGP Speaker resource within OpenStack.

        This resource allows you to configure a BGP speaker that can be associated with
        a BGP peer to exchange routing information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        network1 = openstack.networking.Network("network1", name="network1")
        peer1 = openstack.networking.BgpPeerV2("peer_1",
            name="bgp_peer_1",
            peer_ip="192.0.2.10",
            remote_as=65001,
            auth_type="md5",
            password="supersecret")
        speaker1 = openstack.networking.BgpSpeakerV2("speaker_1",
            name="bgp_speaker_1",
            ip_version=4,
            local_as=65000,
            networks=[network1.id],
            peers=[peer1_opestack_networking_bgp_peer_v2["id"]])
        ```

        ## Import

        BGP speakers can be imported using their ID:

        ```sh
        $ pulumi import openstack:networking/bgpSpeakerV2:BgpSpeakerV2 speaker_1 8a2ad402-b805-46bf-a60b-008573ca2844
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] advertise_floating_ip_host_routes: A boolean value indicating
               whether to advertise floating IP host routes. Defaults to `true`.
        :param pulumi.Input[_builtins.bool] advertise_tenant_networks: A boolean value indicating whether to
               advertise tenant networks. Defaults to `true`.
        :param pulumi.Input[_builtins.int] ip_version: The IP version of the BGP speaker. Valid values are
               `4` or `6`. Defaults to `4`. Changing this creates a new BGP speaker.
        :param pulumi.Input[_builtins.int] local_as: The local autonomous system number (ASN) for the BGP
               speaker. This is a mandatory field and must be specified. Changing this
               creates a new BGP speaker.
        :param pulumi.Input[_builtins.str] name: A name for the BGP speaker.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] networks: A list of network IDs to associate with the BGP speaker.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] peers: A list of BGP peer IDs to associate with the BGP speaker.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a Neutron network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new BGP
               speaker.
        :param pulumi.Input[_builtins.str] tenant_id: The tenant/project ID. Required if admin privileges
               are used. Changing this creates a new BGP speaker.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BgpSpeakerV2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V2 Neutron BGP Speaker resource within OpenStack.

        This resource allows you to configure a BGP speaker that can be associated with
        a BGP peer to exchange routing information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        network1 = openstack.networking.Network("network1", name="network1")
        peer1 = openstack.networking.BgpPeerV2("peer_1",
            name="bgp_peer_1",
            peer_ip="192.0.2.10",
            remote_as=65001,
            auth_type="md5",
            password="supersecret")
        speaker1 = openstack.networking.BgpSpeakerV2("speaker_1",
            name="bgp_speaker_1",
            ip_version=4,
            local_as=65000,
            networks=[network1.id],
            peers=[peer1_opestack_networking_bgp_peer_v2["id"]])
        ```

        ## Import

        BGP speakers can be imported using their ID:

        ```sh
        $ pulumi import openstack:networking/bgpSpeakerV2:BgpSpeakerV2 speaker_1 8a2ad402-b805-46bf-a60b-008573ca2844
        ```


        :param str resource_name: The name of the resource.
        :param BgpSpeakerV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BgpSpeakerV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 advertise_floating_ip_host_routes: Optional[pulumi.Input[_builtins.bool]] = None,
                 advertise_tenant_networks: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.int]] = None,
                 local_as: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 peers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BgpSpeakerV2Args.__new__(BgpSpeakerV2Args)

            __props__.__dict__["advertise_floating_ip_host_routes"] = advertise_floating_ip_host_routes
            __props__.__dict__["advertise_tenant_networks"] = advertise_tenant_networks
            __props__.__dict__["ip_version"] = ip_version
            if local_as is None and not opts.urn:
                raise TypeError("Missing required property 'local_as'")
            __props__.__dict__["local_as"] = local_as
            __props__.__dict__["name"] = name
            __props__.__dict__["networks"] = networks
            __props__.__dict__["peers"] = peers
            __props__.__dict__["region"] = region
            __props__.__dict__["tenant_id"] = tenant_id
            __props__.__dict__["advertised_routes"] = None
        super(BgpSpeakerV2, __self__).__init__(
            'openstack:networking/bgpSpeakerV2:BgpSpeakerV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            advertise_floating_ip_host_routes: Optional[pulumi.Input[_builtins.bool]] = None,
            advertise_tenant_networks: Optional[pulumi.Input[_builtins.bool]] = None,
            advertised_routes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BgpSpeakerV2AdvertisedRouteArgs', 'BgpSpeakerV2AdvertisedRouteArgsDict']]]]] = None,
            ip_version: Optional[pulumi.Input[_builtins.int]] = None,
            local_as: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            peers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            tenant_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'BgpSpeakerV2':
        """
        Get an existing BgpSpeakerV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] advertise_floating_ip_host_routes: A boolean value indicating
               whether to advertise floating IP host routes. Defaults to `true`.
        :param pulumi.Input[_builtins.bool] advertise_tenant_networks: A boolean value indicating whether to
               advertise tenant networks. Defaults to `true`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BgpSpeakerV2AdvertisedRouteArgs', 'BgpSpeakerV2AdvertisedRouteArgsDict']]]] advertised_routes: A list of dictionaries containing the `destination` and
               `next_hop` for each route advertised by the BGP speaker. This attribute is
               only populated after the BGP speaker has been created and has established BGP
               sessions with its peers.
        :param pulumi.Input[_builtins.int] ip_version: The IP version of the BGP speaker. Valid values are
               `4` or `6`. Defaults to `4`. Changing this creates a new BGP speaker.
        :param pulumi.Input[_builtins.int] local_as: The local autonomous system number (ASN) for the BGP
               speaker. This is a mandatory field and must be specified. Changing this
               creates a new BGP speaker.
        :param pulumi.Input[_builtins.str] name: A name for the BGP speaker.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] networks: A list of network IDs to associate with the BGP speaker.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] peers: A list of BGP peer IDs to associate with the BGP speaker.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a Neutron network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new BGP
               speaker.
        :param pulumi.Input[_builtins.str] tenant_id: The tenant/project ID. Required if admin privileges
               are used. Changing this creates a new BGP speaker.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BgpSpeakerV2State.__new__(_BgpSpeakerV2State)

        __props__.__dict__["advertise_floating_ip_host_routes"] = advertise_floating_ip_host_routes
        __props__.__dict__["advertise_tenant_networks"] = advertise_tenant_networks
        __props__.__dict__["advertised_routes"] = advertised_routes
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["local_as"] = local_as
        __props__.__dict__["name"] = name
        __props__.__dict__["networks"] = networks
        __props__.__dict__["peers"] = peers
        __props__.__dict__["region"] = region
        __props__.__dict__["tenant_id"] = tenant_id
        return BgpSpeakerV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="advertiseFloatingIpHostRoutes")
    def advertise_floating_ip_host_routes(self) -> pulumi.Output[_builtins.bool]:
        """
        A boolean value indicating
        whether to advertise floating IP host routes. Defaults to `true`.
        """
        return pulumi.get(self, "advertise_floating_ip_host_routes")

    @_builtins.property
    @pulumi.getter(name="advertiseTenantNetworks")
    def advertise_tenant_networks(self) -> pulumi.Output[_builtins.bool]:
        """
        A boolean value indicating whether to
        advertise tenant networks. Defaults to `true`.
        """
        return pulumi.get(self, "advertise_tenant_networks")

    @_builtins.property
    @pulumi.getter(name="advertisedRoutes")
    def advertised_routes(self) -> pulumi.Output[Sequence['outputs.BgpSpeakerV2AdvertisedRoute']]:
        """
        A list of dictionaries containing the `destination` and
        `next_hop` for each route advertised by the BGP speaker. This attribute is
        only populated after the BGP speaker has been created and has established BGP
        sessions with its peers.
        """
        return pulumi.get(self, "advertised_routes")

    @_builtins.property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The IP version of the BGP speaker. Valid values are
        `4` or `6`. Defaults to `4`. Changing this creates a new BGP speaker.
        """
        return pulumi.get(self, "ip_version")

    @_builtins.property
    @pulumi.getter(name="localAs")
    def local_as(self) -> pulumi.Output[_builtins.int]:
        """
        The local autonomous system number (ASN) for the BGP
        speaker. This is a mandatory field and must be specified. Changing this
        creates a new BGP speaker.
        """
        return pulumi.get(self, "local_as")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A name for the BGP speaker.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def networks(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of network IDs to associate with the BGP speaker.
        """
        return pulumi.get(self, "networks")

    @_builtins.property
    @pulumi.getter
    def peers(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of BGP peer IDs to associate with the BGP speaker.
        """
        return pulumi.get(self, "peers")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a Neutron network. If omitted, the
        `region` argument of the provider is used. Changing this creates a new BGP
        speaker.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[_builtins.str]:
        """
        The tenant/project ID. Required if admin privileges
        are used. Changing this creates a new BGP speaker.
        """
        return pulumi.get(self, "tenant_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['QuotaSetV2Args', 'QuotaSetV2']

@pulumi.input_type
class QuotaSetV2Args:
    def __init__(__self__, *,
                 project_id: pulumi.Input[_builtins.str],
                 cores: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_ips: Optional[pulumi.Input[_builtins.int]] = None,
                 floating_ips: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_file_content_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_file_path_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_files: Optional[pulumi.Input[_builtins.int]] = None,
                 instances: Optional[pulumi.Input[_builtins.int]] = None,
                 key_pairs: Optional[pulumi.Input[_builtins.int]] = None,
                 metadata_items: Optional[pulumi.Input[_builtins.int]] = None,
                 ram: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 security_group_rules: Optional[pulumi.Input[_builtins.int]] = None,
                 security_groups: Optional[pulumi.Input[_builtins.int]] = None,
                 server_group_members: Optional[pulumi.Input[_builtins.int]] = None,
                 server_groups: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a QuotaSetV2 resource.

        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas.
               Changing this creates a new quotaset.
        :param pulumi.Input[_builtins.int] cores: Quota value for cores.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] fixed_ips: Quota value for fixed IPs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] floating_ips: Quota value for floating IPs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_file_content_bytes: Quota value for content bytes
               of injected files. Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_file_path_bytes: Quota value for path bytes of
               injected files. Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_files: Quota value for injected files.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] instances: Quota value for instances.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] key_pairs: Quota value for key pairs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] metadata_items: Quota value for metadata items.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] ram: Quota value for RAM.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.str] region: The region in which to create the volume. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.int] security_group_rules: Quota value for security group rules.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] security_groups: Quota value for security groups.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] server_group_members: Quota value for server groups members.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] server_groups: Quota value for server groups.
               Changing this updates the existing quotaset.
        """
        pulumi.set(__self__, "project_id", project_id)
        if cores is not None:
            pulumi.set(__self__, "cores", cores)
        if fixed_ips is not None:
            pulumi.set(__self__, "fixed_ips", fixed_ips)
        if floating_ips is not None:
            pulumi.set(__self__, "floating_ips", floating_ips)
        if injected_file_content_bytes is not None:
            pulumi.set(__self__, "injected_file_content_bytes", injected_file_content_bytes)
        if injected_file_path_bytes is not None:
            pulumi.set(__self__, "injected_file_path_bytes", injected_file_path_bytes)
        if injected_files is not None:
            pulumi.set(__self__, "injected_files", injected_files)
        if instances is not None:
            pulumi.set(__self__, "instances", instances)
        if key_pairs is not None:
            pulumi.set(__self__, "key_pairs", key_pairs)
        if metadata_items is not None:
            pulumi.set(__self__, "metadata_items", metadata_items)
        if ram is not None:
            pulumi.set(__self__, "ram", ram)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if security_group_rules is not None:
            pulumi.set(__self__, "security_group_rules", security_group_rules)
        if security_groups is not None:
            pulumi.set(__self__, "security_groups", security_groups)
        if server_group_members is not None:
            pulumi.set(__self__, "server_group_members", server_group_members)
        if server_groups is not None:
            pulumi.set(__self__, "server_groups", server_groups)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the project to manage quotas.
        Changing this creates a new quotaset.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def cores(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for cores.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "cores")

    @cores.setter
    def cores(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "cores", value)

    @_builtins.property
    @pulumi.getter(name="fixedIps")
    def fixed_ips(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for fixed IPs.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "fixed_ips")

    @fixed_ips.setter
    def fixed_ips(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "fixed_ips", value)

    @_builtins.property
    @pulumi.getter(name="floatingIps")
    def floating_ips(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for floating IPs.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "floating_ips")

    @floating_ips.setter
    def floating_ips(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "floating_ips", value)

    @_builtins.property
    @pulumi.getter(name="injectedFileContentBytes")
    def injected_file_content_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for content bytes
        of injected files. Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "injected_file_content_bytes")

    @injected_file_content_bytes.setter
    def injected_file_content_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "injected_file_content_bytes", value)

    @_builtins.property
    @pulumi.getter(name="injectedFilePathBytes")
    def injected_file_path_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for path bytes of
        injected files. Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "injected_file_path_bytes")

    @injected_file_path_bytes.setter
    def injected_file_path_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "injected_file_path_bytes", value)

    @_builtins.property
    @pulumi.getter(name="injectedFiles")
    def injected_files(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for injected files.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "injected_files")

    @injected_files.setter
    def injected_files(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "injected_files", value)

    @_builtins.property
    @pulumi.getter
    def instances(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for instances.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "instances")

    @instances.setter
    def instances(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "instances", value)

    @_builtins.property
    @pulumi.getter(name="keyPairs")
    def key_pairs(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for key pairs.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "key_pairs")

    @key_pairs.setter
    def key_pairs(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "key_pairs", value)

    @_builtins.property
    @pulumi.getter(name="metadataItems")
    def metadata_items(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for metadata items.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "metadata_items")

    @metadata_items.setter
    def metadata_items(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "metadata_items", value)

    @_builtins.property
    @pulumi.getter
    def ram(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for RAM.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "ram")

    @ram.setter
    def ram(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ram", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to create the volume. If
        omitted, the `region` argument of the provider is used. Changing this
        creates a new quotaset.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="securityGroupRules")
    def security_group_rules(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for security group rules.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "security_group_rules")

    @security_group_rules.setter
    def security_group_rules(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "security_group_rules", value)

    @_builtins.property
    @pulumi.getter(name="securityGroups")
    def security_groups(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for security groups.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "security_groups")

    @security_groups.setter
    def security_groups(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "security_groups", value)

    @_builtins.property
    @pulumi.getter(name="serverGroupMembers")
    def server_group_members(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for server groups members.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "server_group_members")

    @server_group_members.setter
    def server_group_members(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "server_group_members", value)

    @_builtins.property
    @pulumi.getter(name="serverGroups")
    def server_groups(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for server groups.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "server_groups")

    @server_groups.setter
    def server_groups(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "server_groups", value)


@pulumi.input_type
class _QuotaSetV2State:
    def __init__(__self__, *,
                 cores: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_ips: Optional[pulumi.Input[_builtins.int]] = None,
                 floating_ips: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_file_content_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_file_path_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_files: Optional[pulumi.Input[_builtins.int]] = None,
                 instances: Optional[pulumi.Input[_builtins.int]] = None,
                 key_pairs: Optional[pulumi.Input[_builtins.int]] = None,
                 metadata_items: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ram: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 security_group_rules: Optional[pulumi.Input[_builtins.int]] = None,
                 security_groups: Optional[pulumi.Input[_builtins.int]] = None,
                 server_group_members: Optional[pulumi.Input[_builtins.int]] = None,
                 server_groups: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering QuotaSetV2 resources.

        :param pulumi.Input[_builtins.int] cores: Quota value for cores.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] fixed_ips: Quota value for fixed IPs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] floating_ips: Quota value for floating IPs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_file_content_bytes: Quota value for content bytes
               of injected files. Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_file_path_bytes: Quota value for path bytes of
               injected files. Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_files: Quota value for injected files.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] instances: Quota value for instances.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] key_pairs: Quota value for key pairs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] metadata_items: Quota value for metadata items.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas.
               Changing this creates a new quotaset.
        :param pulumi.Input[_builtins.int] ram: Quota value for RAM.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.str] region: The region in which to create the volume. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.int] security_group_rules: Quota value for security group rules.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] security_groups: Quota value for security groups.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] server_group_members: Quota value for server groups members.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] server_groups: Quota value for server groups.
               Changing this updates the existing quotaset.
        """
        if cores is not None:
            pulumi.set(__self__, "cores", cores)
        if fixed_ips is not None:
            pulumi.set(__self__, "fixed_ips", fixed_ips)
        if floating_ips is not None:
            pulumi.set(__self__, "floating_ips", floating_ips)
        if injected_file_content_bytes is not None:
            pulumi.set(__self__, "injected_file_content_bytes", injected_file_content_bytes)
        if injected_file_path_bytes is not None:
            pulumi.set(__self__, "injected_file_path_bytes", injected_file_path_bytes)
        if injected_files is not None:
            pulumi.set(__self__, "injected_files", injected_files)
        if instances is not None:
            pulumi.set(__self__, "instances", instances)
        if key_pairs is not None:
            pulumi.set(__self__, "key_pairs", key_pairs)
        if metadata_items is not None:
            pulumi.set(__self__, "metadata_items", metadata_items)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if ram is not None:
            pulumi.set(__self__, "ram", ram)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if security_group_rules is not None:
            pulumi.set(__self__, "security_group_rules", security_group_rules)
        if security_groups is not None:
            pulumi.set(__self__, "security_groups", security_groups)
        if server_group_members is not None:
            pulumi.set(__self__, "server_group_members", server_group_members)
        if server_groups is not None:
            pulumi.set(__self__, "server_groups", server_groups)

    @_builtins.property
    @pulumi.getter
    def cores(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for cores.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "cores")

    @cores.setter
    def cores(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "cores", value)

    @_builtins.property
    @pulumi.getter(name="fixedIps")
    def fixed_ips(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for fixed IPs.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "fixed_ips")

    @fixed_ips.setter
    def fixed_ips(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "fixed_ips", value)

    @_builtins.property
    @pulumi.getter(name="floatingIps")
    def floating_ips(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for floating IPs.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "floating_ips")

    @floating_ips.setter
    def floating_ips(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "floating_ips", value)

    @_builtins.property
    @pulumi.getter(name="injectedFileContentBytes")
    def injected_file_content_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for content bytes
        of injected files. Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "injected_file_content_bytes")

    @injected_file_content_bytes.setter
    def injected_file_content_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "injected_file_content_bytes", value)

    @_builtins.property
    @pulumi.getter(name="injectedFilePathBytes")
    def injected_file_path_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for path bytes of
        injected files. Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "injected_file_path_bytes")

    @injected_file_path_bytes.setter
    def injected_file_path_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "injected_file_path_bytes", value)

    @_builtins.property
    @pulumi.getter(name="injectedFiles")
    def injected_files(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for injected files.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "injected_files")

    @injected_files.setter
    def injected_files(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "injected_files", value)

    @_builtins.property
    @pulumi.getter
    def instances(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for instances.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "instances")

    @instances.setter
    def instances(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "instances", value)

    @_builtins.property
    @pulumi.getter(name="keyPairs")
    def key_pairs(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for key pairs.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "key_pairs")

    @key_pairs.setter
    def key_pairs(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "key_pairs", value)

    @_builtins.property
    @pulumi.getter(name="metadataItems")
    def metadata_items(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for metadata items.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "metadata_items")

    @metadata_items.setter
    def metadata_items(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "metadata_items", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the project to manage quotas.
        Changing this creates a new quotaset.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def ram(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for RAM.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "ram")

    @ram.setter
    def ram(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ram", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to create the volume. If
        omitted, the `region` argument of the provider is used. Changing this
        creates a new quotaset.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="securityGroupRules")
    def security_group_rules(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for security group rules.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "security_group_rules")

    @security_group_rules.setter
    def security_group_rules(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "security_group_rules", value)

    @_builtins.property
    @pulumi.getter(name="securityGroups")
    def security_groups(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for security groups.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "security_groups")

    @security_groups.setter
    def security_groups(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "security_groups", value)

    @_builtins.property
    @pulumi.getter(name="serverGroupMembers")
    def server_group_members(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for server groups members.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "server_group_members")

    @server_group_members.setter
    def server_group_members(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "server_group_members", value)

    @_builtins.property
    @pulumi.getter(name="serverGroups")
    def server_groups(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for server groups.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "server_groups")

    @server_groups.setter
    def server_groups(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "server_groups", value)


@pulumi.type_token("openstack:compute/quotaSetV2:QuotaSetV2")
class QuotaSetV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cores: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_ips: Optional[pulumi.Input[_builtins.int]] = None,
                 floating_ips: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_file_content_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_file_path_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_files: Optional[pulumi.Input[_builtins.int]] = None,
                 instances: Optional[pulumi.Input[_builtins.int]] = None,
                 key_pairs: Optional[pulumi.Input[_builtins.int]] = None,
                 metadata_items: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ram: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 security_group_rules: Optional[pulumi.Input[_builtins.int]] = None,
                 security_groups: Optional[pulumi.Input[_builtins.int]] = None,
                 server_group_members: Optional[pulumi.Input[_builtins.int]] = None,
                 server_groups: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Manages a V2 compute quotaset resource within OpenStack.

        > **Note:** This usually requires admin privileges.

        > **Note:** This resource has a no-op deletion so no actual actions will be done against the OpenStack API
            in case of delete call.

        ## Import

        Quotasets can be imported using the `project_id/region_name`, e.g.

        ```sh
        $ pulumi import openstack:compute/quotaSetV2:QuotaSetV2 quotaset_1 2a0f2240-c5e6-41de-896d-e80d97428d6b/region_1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] cores: Quota value for cores.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] fixed_ips: Quota value for fixed IPs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] floating_ips: Quota value for floating IPs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_file_content_bytes: Quota value for content bytes
               of injected files. Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_file_path_bytes: Quota value for path bytes of
               injected files. Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_files: Quota value for injected files.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] instances: Quota value for instances.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] key_pairs: Quota value for key pairs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] metadata_items: Quota value for metadata items.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas.
               Changing this creates a new quotaset.
        :param pulumi.Input[_builtins.int] ram: Quota value for RAM.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.str] region: The region in which to create the volume. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.int] security_group_rules: Quota value for security group rules.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] security_groups: Quota value for security groups.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] server_group_members: Quota value for server groups members.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] server_groups: Quota value for server groups.
               Changing this updates the existing quotaset.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: QuotaSetV2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V2 compute quotaset resource within OpenStack.

        > **Note:** This usually requires admin privileges.

        > **Note:** This resource has a no-op deletion so no actual actions will be done against the OpenStack API
            in case of delete call.

        ## Import

        Quotasets can be imported using the `project_id/region_name`, e.g.

        ```sh
        $ pulumi import openstack:compute/quotaSetV2:QuotaSetV2 quotaset_1 2a0f2240-c5e6-41de-896d-e80d97428d6b/region_1
        ```


        :param str resource_name: The name of the resource.
        :param QuotaSetV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(QuotaSetV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cores: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_ips: Optional[pulumi.Input[_builtins.int]] = None,
                 floating_ips: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_file_content_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_file_path_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 injected_files: Optional[pulumi.Input[_builtins.int]] = None,
                 instances: Optional[pulumi.Input[_builtins.int]] = None,
                 key_pairs: Optional[pulumi.Input[_builtins.int]] = None,
                 metadata_items: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ram: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 security_group_rules: Optional[pulumi.Input[_builtins.int]] = None,
                 security_groups: Optional[pulumi.Input[_builtins.int]] = None,
                 server_group_members: Optional[pulumi.Input[_builtins.int]] = None,
                 server_groups: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = QuotaSetV2Args.__new__(QuotaSetV2Args)

            __props__.__dict__["cores"] = cores
            __props__.__dict__["fixed_ips"] = fixed_ips
            __props__.__dict__["floating_ips"] = floating_ips
            __props__.__dict__["injected_file_content_bytes"] = injected_file_content_bytes
            __props__.__dict__["injected_file_path_bytes"] = injected_file_path_bytes
            __props__.__dict__["injected_files"] = injected_files
            __props__.__dict__["instances"] = instances
            __props__.__dict__["key_pairs"] = key_pairs
            __props__.__dict__["metadata_items"] = metadata_items
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["ram"] = ram
            __props__.__dict__["region"] = region
            __props__.__dict__["security_group_rules"] = security_group_rules
            __props__.__dict__["security_groups"] = security_groups
            __props__.__dict__["server_group_members"] = server_group_members
            __props__.__dict__["server_groups"] = server_groups
        super(QuotaSetV2, __self__).__init__(
            'openstack:compute/quotaSetV2:QuotaSetV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cores: Optional[pulumi.Input[_builtins.int]] = None,
            fixed_ips: Optional[pulumi.Input[_builtins.int]] = None,
            floating_ips: Optional[pulumi.Input[_builtins.int]] = None,
            injected_file_content_bytes: Optional[pulumi.Input[_builtins.int]] = None,
            injected_file_path_bytes: Optional[pulumi.Input[_builtins.int]] = None,
            injected_files: Optional[pulumi.Input[_builtins.int]] = None,
            instances: Optional[pulumi.Input[_builtins.int]] = None,
            key_pairs: Optional[pulumi.Input[_builtins.int]] = None,
            metadata_items: Optional[pulumi.Input[_builtins.int]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            ram: Optional[pulumi.Input[_builtins.int]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            security_group_rules: Optional[pulumi.Input[_builtins.int]] = None,
            security_groups: Optional[pulumi.Input[_builtins.int]] = None,
            server_group_members: Optional[pulumi.Input[_builtins.int]] = None,
            server_groups: Optional[pulumi.Input[_builtins.int]] = None) -> 'QuotaSetV2':
        """
        Get an existing QuotaSetV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] cores: Quota value for cores.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] fixed_ips: Quota value for fixed IPs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] floating_ips: Quota value for floating IPs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_file_content_bytes: Quota value for content bytes
               of injected files. Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_file_path_bytes: Quota value for path bytes of
               injected files. Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] injected_files: Quota value for injected files.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] instances: Quota value for instances.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] key_pairs: Quota value for key pairs.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] metadata_items: Quota value for metadata items.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas.
               Changing this creates a new quotaset.
        :param pulumi.Input[_builtins.int] ram: Quota value for RAM.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.str] region: The region in which to create the volume. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.int] security_group_rules: Quota value for security group rules.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] security_groups: Quota value for security groups.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] server_group_members: Quota value for server groups members.
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] server_groups: Quota value for server groups.
               Changing this updates the existing quotaset.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _QuotaSetV2State.__new__(_QuotaSetV2State)

        __props__.__dict__["cores"] = cores
        __props__.__dict__["fixed_ips"] = fixed_ips
        __props__.__dict__["floating_ips"] = floating_ips
        __props__.__dict__["injected_file_content_bytes"] = injected_file_content_bytes
        __props__.__dict__["injected_file_path_bytes"] = injected_file_path_bytes
        __props__.__dict__["injected_files"] = injected_files
        __props__.__dict__["instances"] = instances
        __props__.__dict__["key_pairs"] = key_pairs
        __props__.__dict__["metadata_items"] = metadata_items
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["ram"] = ram
        __props__.__dict__["region"] = region
        __props__.__dict__["security_group_rules"] = security_group_rules
        __props__.__dict__["security_groups"] = security_groups
        __props__.__dict__["server_group_members"] = server_group_members
        __props__.__dict__["server_groups"] = server_groups
        return QuotaSetV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def cores(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for cores.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "cores")

    @_builtins.property
    @pulumi.getter(name="fixedIps")
    def fixed_ips(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for fixed IPs.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "fixed_ips")

    @_builtins.property
    @pulumi.getter(name="floatingIps")
    def floating_ips(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for floating IPs.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "floating_ips")

    @_builtins.property
    @pulumi.getter(name="injectedFileContentBytes")
    def injected_file_content_bytes(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for content bytes
        of injected files. Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "injected_file_content_bytes")

    @_builtins.property
    @pulumi.getter(name="injectedFilePathBytes")
    def injected_file_path_bytes(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for path bytes of
        injected files. Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "injected_file_path_bytes")

    @_builtins.property
    @pulumi.getter(name="injectedFiles")
    def injected_files(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for injected files.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "injected_files")

    @_builtins.property
    @pulumi.getter
    def instances(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for instances.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "instances")

    @_builtins.property
    @pulumi.getter(name="keyPairs")
    def key_pairs(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for key pairs.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "key_pairs")

    @_builtins.property
    @pulumi.getter(name="metadataItems")
    def metadata_items(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for metadata items.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "metadata_items")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the project to manage quotas.
        Changing this creates a new quotaset.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def ram(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for RAM.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "ram")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to create the volume. If
        omitted, the `region` argument of the provider is used. Changing this
        creates a new quotaset.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="securityGroupRules")
    def security_group_rules(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for security group rules.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "security_group_rules")

    @_builtins.property
    @pulumi.getter(name="securityGroups")
    def security_groups(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for security groups.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "security_groups")

    @_builtins.property
    @pulumi.getter(name="serverGroupMembers")
    def server_group_members(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for server groups members.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "server_group_members")

    @_builtins.property
    @pulumi.getter(name="serverGroups")
    def server_groups(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for server groups.
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "server_groups")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AggregateV2Args', 'AggregateV2']

@pulumi.input_type
class AggregateV2Args:
    def __init__(__self__, *,
                 hosts: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AggregateV2 resource.

        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] hosts: The list of hosts contained in the Host Aggregate. The hosts must be added
               to Openstack and visible in the web interface, or the provider will fail to add them to the host
               aggregate.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] metadata: The metadata of the Host Aggregate. Can be useful to indicate scheduler hints.
        :param pulumi.Input[_builtins.str] name: The name of the Host Aggregate
        :param pulumi.Input[_builtins.str] region: The region in which to create the Host Aggregate. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new Host Aggregate.
        :param pulumi.Input[_builtins.str] zone: The name of the Availability Zone to use. If ommited, it will take the default
               availability zone.
        """
        if hosts is not None:
            pulumi.set(__self__, "hosts", hosts)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def hosts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of hosts contained in the Host Aggregate. The hosts must be added
        to Openstack and visible in the web interface, or the provider will fail to add them to the host
        aggregate.
        """
        return pulumi.get(self, "hosts")

    @hosts.setter
    def hosts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "hosts", value)

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The metadata of the Host Aggregate. Can be useful to indicate scheduler hints.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "metadata", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Host Aggregate
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to create the Host Aggregate. If
        omitted, the `region` argument of the provider is used. Changing this
        creates a new Host Aggregate.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Availability Zone to use. If ommited, it will take the default
        availability zone.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _AggregateV2State:
    def __init__(__self__, *,
                 hosts: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AggregateV2 resources.

        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] hosts: The list of hosts contained in the Host Aggregate. The hosts must be added
               to Openstack and visible in the web interface, or the provider will fail to add them to the host
               aggregate.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] metadata: The metadata of the Host Aggregate. Can be useful to indicate scheduler hints.
        :param pulumi.Input[_builtins.str] name: The name of the Host Aggregate
        :param pulumi.Input[_builtins.str] region: The region in which to create the Host Aggregate. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new Host Aggregate.
        :param pulumi.Input[_builtins.str] zone: The name of the Availability Zone to use. If ommited, it will take the default
               availability zone.
        """
        if hosts is not None:
            pulumi.set(__self__, "hosts", hosts)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def hosts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of hosts contained in the Host Aggregate. The hosts must be added
        to Openstack and visible in the web interface, or the provider will fail to add them to the host
        aggregate.
        """
        return pulumi.get(self, "hosts")

    @hosts.setter
    def hosts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "hosts", value)

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The metadata of the Host Aggregate. Can be useful to indicate scheduler hints.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "metadata", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Host Aggregate
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to create the Host Aggregate. If
        omitted, the `region` argument of the provider is used. Changing this
        creates a new Host Aggregate.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Availability Zone to use. If ommited, it will take the default
        availability zone.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("openstack:compute/aggregateV2:AggregateV2")
class AggregateV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 hosts: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a Host Aggregate within Openstack Nova.

        ## Example Usage

        ### Full example

        ```python
        import pulumi
        import pulumi_openstack as openstack

        dell_servers = openstack.compute.AggregateV2("dell_servers",
            region="RegionOne",
            name="dell_servers",
            zone="nova",
            metadata={
                "cpus": "56",
            },
            hosts=[
                "myhost01.example.com",
                "myhost02.example.com",
            ])
        ```

        ### Minimum required example

        ```python
        import pulumi
        import pulumi_openstack as openstack

        test = openstack.compute.AggregateV2("test", name="test")
        ```

        ## Import

        You can import an existing Host Aggregate by their ID.
        ```sh
        $ pulumi import openstack:compute/aggregateV2:AggregateV2 myaggregate 24
        ```

        The ID can be obtained with an openstack command:
        ```sh
        $ openstack aggregate list
        +----+------+-------------------+
        | ID | Name | Availability Zone |
        +----+------+-------------------+
        | 59 | test | None              |
        +----+------+-------------------+
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] hosts: The list of hosts contained in the Host Aggregate. The hosts must be added
               to Openstack and visible in the web interface, or the provider will fail to add them to the host
               aggregate.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] metadata: The metadata of the Host Aggregate. Can be useful to indicate scheduler hints.
        :param pulumi.Input[_builtins.str] name: The name of the Host Aggregate
        :param pulumi.Input[_builtins.str] region: The region in which to create the Host Aggregate. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new Host Aggregate.
        :param pulumi.Input[_builtins.str] zone: The name of the Availability Zone to use. If ommited, it will take the default
               availability zone.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AggregateV2Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Host Aggregate within Openstack Nova.

        ## Example Usage

        ### Full example

        ```python
        import pulumi
        import pulumi_openstack as openstack

        dell_servers = openstack.compute.AggregateV2("dell_servers",
            region="RegionOne",
            name="dell_servers",
            zone="nova",
            metadata={
                "cpus": "56",
            },
            hosts=[
                "myhost01.example.com",
                "myhost02.example.com",
            ])
        ```

        ### Minimum required example

        ```python
        import pulumi
        import pulumi_openstack as openstack

        test = openstack.compute.AggregateV2("test", name="test")
        ```

        ## Import

        You can import an existing Host Aggregate by their ID.
        ```sh
        $ pulumi import openstack:compute/aggregateV2:AggregateV2 myaggregate 24
        ```

        The ID can be obtained with an openstack command:
        ```sh
        $ openstack aggregate list
        +----+------+-------------------+
        | ID | Name | Availability Zone |
        +----+------+-------------------+
        | 59 | test | None              |
        +----+------+-------------------+
        ```


        :param str resource_name: The name of the resource.
        :param AggregateV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AggregateV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 hosts: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AggregateV2Args.__new__(AggregateV2Args)

            __props__.__dict__["hosts"] = hosts
            __props__.__dict__["metadata"] = metadata
            __props__.__dict__["name"] = name
            __props__.__dict__["region"] = region
            __props__.__dict__["zone"] = zone
        super(AggregateV2, __self__).__init__(
            'openstack:compute/aggregateV2:AggregateV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            hosts: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'AggregateV2':
        """
        Get an existing AggregateV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] hosts: The list of hosts contained in the Host Aggregate. The hosts must be added
               to Openstack and visible in the web interface, or the provider will fail to add them to the host
               aggregate.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] metadata: The metadata of the Host Aggregate. Can be useful to indicate scheduler hints.
        :param pulumi.Input[_builtins.str] name: The name of the Host Aggregate
        :param pulumi.Input[_builtins.str] region: The region in which to create the Host Aggregate. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new Host Aggregate.
        :param pulumi.Input[_builtins.str] zone: The name of the Availability Zone to use. If ommited, it will take the default
               availability zone.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AggregateV2State.__new__(_AggregateV2State)

        __props__.__dict__["hosts"] = hosts
        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["zone"] = zone
        return AggregateV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def hosts(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The list of hosts contained in the Host Aggregate. The hosts must be added
        to Openstack and visible in the web interface, or the provider will fail to add them to the host
        aggregate.
        """
        return pulumi.get(self, "hosts")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        The metadata of the Host Aggregate. Can be useful to indicate scheduler hints.
        """
        return pulumi.get(self, "metadata")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Host Aggregate
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to create the Host Aggregate. If
        omitted, the `region` argument of the provider is used. Changing this
        creates a new Host Aggregate.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The name of the Availability Zone to use. If ommited, it will take the default
        availability zone.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MembersArgs', 'Members']

@pulumi.input_type
class MembersArgs:
    def __init__(__self__, *,
                 pool_id: pulumi.Input[_builtins.str],
                 members: Optional[pulumi.Input[Sequence[pulumi.Input['MembersMemberArgs']]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Members resource.

        :param pulumi.Input[_builtins.str] pool_id: The id of the pool that members will be assigned to.
               Changing this creates a new members resource.
        :param pulumi.Input[Sequence[pulumi.Input['MembersMemberArgs']]] members: A set of dictionaries containing member parameters. The
               structure is described below.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create pool members. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               members resource.
        """
        pulumi.set(__self__, "pool_id", pool_id)
        if members is not None:
            pulumi.set(__self__, "members", members)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the pool that members will be assigned to.
        Changing this creates a new members resource.
        """
        return pulumi.get(self, "pool_id")

    @pool_id.setter
    def pool_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pool_id", value)

    @_builtins.property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MembersMemberArgs']]]]:
        """
        A set of dictionaries containing member parameters. The
        structure is described below.
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MembersMemberArgs']]]]):
        pulumi.set(self, "members", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create pool members. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        members resource.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _MembersState:
    def __init__(__self__, *,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input['MembersMemberArgs']]]] = None,
                 pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Members resources.

        :param pulumi.Input[Sequence[pulumi.Input['MembersMemberArgs']]] members: A set of dictionaries containing member parameters. The
               structure is described below.
        :param pulumi.Input[_builtins.str] pool_id: The id of the pool that members will be assigned to.
               Changing this creates a new members resource.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create pool members. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               members resource.
        """
        if members is not None:
            pulumi.set(__self__, "members", members)
        if pool_id is not None:
            pulumi.set(__self__, "pool_id", pool_id)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MembersMemberArgs']]]]:
        """
        A set of dictionaries containing member parameters. The
        structure is described below.
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MembersMemberArgs']]]]):
        pulumi.set(self, "members", value)

    @_builtins.property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the pool that members will be assigned to.
        Changing this creates a new members resource.
        """
        return pulumi.get(self, "pool_id")

    @pool_id.setter
    def pool_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pool_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create pool members. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        members resource.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.type_token("openstack:loadbalancer/members:Members")
class Members(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MembersMemberArgs', 'MembersMemberArgsDict']]]]] = None,
                 pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a V2 members resource within OpenStack (batch members update).

        > **Note:** This resource has attributes that depend on octavia minor versions.
        Please ensure your Openstack cloud supports the required minor version.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        members1 = openstack.loadbalancer.Members("members_1",
            pool_id="935685fb-a896-40f9-9ff4-ae531a3a00fe",
            members=[
                {
                    "address": "192.168.199.23",
                    "protocol_port": 8080,
                },
                {
                    "address": "192.168.199.24",
                    "protocol_port": 8080,
                },
            ])
        ```

        ## Import

        Load Balancer Pool Members can be imported using the Pool ID, e.g.:

        ```sh
        $ pulumi import openstack:loadbalancer/members:Members members_1 c22974d2-4c95-4bcb-9819-0afc5ed303d5
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['MembersMemberArgs', 'MembersMemberArgsDict']]]] members: A set of dictionaries containing member parameters. The
               structure is described below.
        :param pulumi.Input[_builtins.str] pool_id: The id of the pool that members will be assigned to.
               Changing this creates a new members resource.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create pool members. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               members resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MembersArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V2 members resource within OpenStack (batch members update).

        > **Note:** This resource has attributes that depend on octavia minor versions.
        Please ensure your Openstack cloud supports the required minor version.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        members1 = openstack.loadbalancer.Members("members_1",
            pool_id="935685fb-a896-40f9-9ff4-ae531a3a00fe",
            members=[
                {
                    "address": "192.168.199.23",
                    "protocol_port": 8080,
                },
                {
                    "address": "192.168.199.24",
                    "protocol_port": 8080,
                },
            ])
        ```

        ## Import

        Load Balancer Pool Members can be imported using the Pool ID, e.g.:

        ```sh
        $ pulumi import openstack:loadbalancer/members:Members members_1 c22974d2-4c95-4bcb-9819-0afc5ed303d5
        ```


        :param str resource_name: The name of the resource.
        :param MembersArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MembersArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MembersMemberArgs', 'MembersMemberArgsDict']]]]] = None,
                 pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MembersArgs.__new__(MembersArgs)

            __props__.__dict__["members"] = members
            if pool_id is None and not opts.urn:
                raise TypeError("Missing required property 'pool_id'")
            __props__.__dict__["pool_id"] = pool_id
            __props__.__dict__["region"] = region
        super(Members, __self__).__init__(
            'openstack:loadbalancer/members:Members',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            members: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MembersMemberArgs', 'MembersMemberArgsDict']]]]] = None,
            pool_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None) -> 'Members':
        """
        Get an existing Members resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['MembersMemberArgs', 'MembersMemberArgsDict']]]] members: A set of dictionaries containing member parameters. The
               structure is described below.
        :param pulumi.Input[_builtins.str] pool_id: The id of the pool that members will be assigned to.
               Changing this creates a new members resource.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create pool members. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               members resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MembersState.__new__(_MembersState)

        __props__.__dict__["members"] = members
        __props__.__dict__["pool_id"] = pool_id
        __props__.__dict__["region"] = region
        return Members(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def members(self) -> pulumi.Output[Optional[Sequence['outputs.MembersMember']]]:
        """
        A set of dictionaries containing member parameters. The
        structure is described below.
        """
        return pulumi.get(self, "members")

    @_builtins.property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the pool that members will be assigned to.
        Changing this creates a new members resource.
        """
        return pulumi.get(self, "pool_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create pool members. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        members resource.
        """
        return pulumi.get(self, "region")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RouterRouteArgs', 'RouterRoute']

@pulumi.input_type
class RouterRouteArgs:
    def __init__(__self__, *,
                 destination_cidr: pulumi.Input[_builtins.str],
                 next_hop: pulumi.Input[_builtins.str],
                 router_id: pulumi.Input[_builtins.str],
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a RouterRoute resource.

        :param pulumi.Input[_builtins.str] destination_cidr: CIDR block to match on the packet’s destination IP. Changing
               this creates a new routing entry.
        :param pulumi.Input[_builtins.str] next_hop: IP address of the next hop gateway.  Changing
               this creates a new routing entry.
        :param pulumi.Input[_builtins.str] router_id: ID of the router this routing entry belongs to. Changing
               this creates a new routing entry.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to configure a routing entry on a router. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               routing entry.
        """
        pulumi.set(__self__, "destination_cidr", destination_cidr)
        pulumi.set(__self__, "next_hop", next_hop)
        pulumi.set(__self__, "router_id", router_id)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="destinationCidr")
    def destination_cidr(self) -> pulumi.Input[_builtins.str]:
        """
        CIDR block to match on the packet’s destination IP. Changing
        this creates a new routing entry.
        """
        return pulumi.get(self, "destination_cidr")

    @destination_cidr.setter
    def destination_cidr(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "destination_cidr", value)

    @_builtins.property
    @pulumi.getter(name="nextHop")
    def next_hop(self) -> pulumi.Input[_builtins.str]:
        """
        IP address of the next hop gateway.  Changing
        this creates a new routing entry.
        """
        return pulumi.get(self, "next_hop")

    @next_hop.setter
    def next_hop(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "next_hop", value)

    @_builtins.property
    @pulumi.getter(name="routerId")
    def router_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the router this routing entry belongs to. Changing
        this creates a new routing entry.
        """
        return pulumi.get(self, "router_id")

    @router_id.setter
    def router_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "router_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 networking client.
        A networking client is needed to configure a routing entry on a router. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        routing entry.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _RouterRouteState:
    def __init__(__self__, *,
                 destination_cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 next_hop: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 router_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RouterRoute resources.

        :param pulumi.Input[_builtins.str] destination_cidr: CIDR block to match on the packet’s destination IP. Changing
               this creates a new routing entry.
        :param pulumi.Input[_builtins.str] next_hop: IP address of the next hop gateway.  Changing
               this creates a new routing entry.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to configure a routing entry on a router. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               routing entry.
        :param pulumi.Input[_builtins.str] router_id: ID of the router this routing entry belongs to. Changing
               this creates a new routing entry.
        """
        if destination_cidr is not None:
            pulumi.set(__self__, "destination_cidr", destination_cidr)
        if next_hop is not None:
            pulumi.set(__self__, "next_hop", next_hop)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if router_id is not None:
            pulumi.set(__self__, "router_id", router_id)

    @_builtins.property
    @pulumi.getter(name="destinationCidr")
    def destination_cidr(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        CIDR block to match on the packet’s destination IP. Changing
        this creates a new routing entry.
        """
        return pulumi.get(self, "destination_cidr")

    @destination_cidr.setter
    def destination_cidr(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "destination_cidr", value)

    @_builtins.property
    @pulumi.getter(name="nextHop")
    def next_hop(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IP address of the next hop gateway.  Changing
        this creates a new routing entry.
        """
        return pulumi.get(self, "next_hop")

    @next_hop.setter
    def next_hop(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "next_hop", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 networking client.
        A networking client is needed to configure a routing entry on a router. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        routing entry.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="routerId")
    def router_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the router this routing entry belongs to. Changing
        this creates a new routing entry.
        """
        return pulumi.get(self, "router_id")

    @router_id.setter
    def router_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "router_id", value)


@pulumi.type_token("openstack:networking/routerRoute:RouterRoute")
class RouterRoute(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 destination_cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 next_hop: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 router_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates a routing entry on a OpenStack V2 router.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        router1 = openstack.networking.Router("router_1",
            name="router_1",
            admin_state_up=True)
        network1 = openstack.networking.Network("network_1",
            name="network_1",
            admin_state_up=True)
        subnet1 = openstack.networking.Subnet("subnet_1",
            network_id=network1.id,
            cidr="192.168.199.0/24",
            ip_version=4)
        int1 = openstack.networking.RouterInterface("int_1",
            router_id=router1.id,
            subnet_id=subnet1.id)
        router_route1 = openstack.networking.RouterRoute("router_route_1",
            router_id=router1.id,
            destination_cidr="10.0.1.0/24",
            next_hop="192.168.199.254",
            opts = pulumi.ResourceOptions(depends_on=[int1]))
        ```

        ## Notes

        The `next_hop` IP address must be directly reachable from the router at the ``networking.RouterRoute``
        resource creation time.  You can ensure that by explicitly specifying a dependency on the ``networking.RouterInterface``
        resource that connects the next hop to the router, as in the example above.

        ## Import

        Routing entries can be imported using a combined ID using the following format: ``<router_id>-route-<destination_cidr>-<next_hop>``

        ```sh
        $ pulumi import openstack:networking/routerRoute:RouterRoute router_route_1 686fe248-386c-4f70-9f6c-281607dad079-route-10.0.1.0/24-192.168.199.25
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] destination_cidr: CIDR block to match on the packet’s destination IP. Changing
               this creates a new routing entry.
        :param pulumi.Input[_builtins.str] next_hop: IP address of the next hop gateway.  Changing
               this creates a new routing entry.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to configure a routing entry on a router. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               routing entry.
        :param pulumi.Input[_builtins.str] router_id: ID of the router this routing entry belongs to. Changing
               this creates a new routing entry.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RouterRouteArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a routing entry on a OpenStack V2 router.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        router1 = openstack.networking.Router("router_1",
            name="router_1",
            admin_state_up=True)
        network1 = openstack.networking.Network("network_1",
            name="network_1",
            admin_state_up=True)
        subnet1 = openstack.networking.Subnet("subnet_1",
            network_id=network1.id,
            cidr="192.168.199.0/24",
            ip_version=4)
        int1 = openstack.networking.RouterInterface("int_1",
            router_id=router1.id,
            subnet_id=subnet1.id)
        router_route1 = openstack.networking.RouterRoute("router_route_1",
            router_id=router1.id,
            destination_cidr="10.0.1.0/24",
            next_hop="192.168.199.254",
            opts = pulumi.ResourceOptions(depends_on=[int1]))
        ```

        ## Notes

        The `next_hop` IP address must be directly reachable from the router at the ``networking.RouterRoute``
        resource creation time.  You can ensure that by explicitly specifying a dependency on the ``networking.RouterInterface``
        resource that connects the next hop to the router, as in the example above.

        ## Import

        Routing entries can be imported using a combined ID using the following format: ``<router_id>-route-<destination_cidr>-<next_hop>``

        ```sh
        $ pulumi import openstack:networking/routerRoute:RouterRoute router_route_1 686fe248-386c-4f70-9f6c-281607dad079-route-10.0.1.0/24-192.168.199.25
        ```


        :param str resource_name: The name of the resource.
        :param RouterRouteArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RouterRouteArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 destination_cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 next_hop: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 router_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RouterRouteArgs.__new__(RouterRouteArgs)

            if destination_cidr is None and not opts.urn:
                raise TypeError("Missing required property 'destination_cidr'")
            __props__.__dict__["destination_cidr"] = destination_cidr
            if next_hop is None and not opts.urn:
                raise TypeError("Missing required property 'next_hop'")
            __props__.__dict__["next_hop"] = next_hop
            __props__.__dict__["region"] = region
            if router_id is None and not opts.urn:
                raise TypeError("Missing required property 'router_id'")
            __props__.__dict__["router_id"] = router_id
        super(RouterRoute, __self__).__init__(
            'openstack:networking/routerRoute:RouterRoute',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            destination_cidr: Optional[pulumi.Input[_builtins.str]] = None,
            next_hop: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            router_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'RouterRoute':
        """
        Get an existing RouterRoute resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] destination_cidr: CIDR block to match on the packet’s destination IP. Changing
               this creates a new routing entry.
        :param pulumi.Input[_builtins.str] next_hop: IP address of the next hop gateway.  Changing
               this creates a new routing entry.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to configure a routing entry on a router. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               routing entry.
        :param pulumi.Input[_builtins.str] router_id: ID of the router this routing entry belongs to. Changing
               this creates a new routing entry.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RouterRouteState.__new__(_RouterRouteState)

        __props__.__dict__["destination_cidr"] = destination_cidr
        __props__.__dict__["next_hop"] = next_hop
        __props__.__dict__["region"] = region
        __props__.__dict__["router_id"] = router_id
        return RouterRoute(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="destinationCidr")
    def destination_cidr(self) -> pulumi.Output[_builtins.str]:
        """
        CIDR block to match on the packet’s destination IP. Changing
        this creates a new routing entry.
        """
        return pulumi.get(self, "destination_cidr")

    @_builtins.property
    @pulumi.getter(name="nextHop")
    def next_hop(self) -> pulumi.Output[_builtins.str]:
        """
        IP address of the next hop gateway.  Changing
        this creates a new routing entry.
        """
        return pulumi.get(self, "next_hop")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V2 networking client.
        A networking client is needed to configure a routing entry on a router. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        routing entry.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="routerId")
    def router_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the router this routing entry belongs to. Changing
        this creates a new routing entry.
        """
        return pulumi.get(self, "router_id")

